@@ -58,11 +58,11 @@ class ContentBlock:
 
 # 2. 上下文提供者 (带缓存)
 class ContextProvider(ABC):
-    def __init__(self, name: str):
+    def __init__(self, name: str, visible: bool = True):
         self.name = name
         self._cached_content: Optional[str] = None
         self._is_stale: bool = True
-        self._visible: bool = True
+        self._visible: bool = visible
 
     def __str__(self):
         # This allows the object to be captured when used inside an f-string.
@@ -96,8 +96,15 @@ class ContextProvider(ABC):
             return ContentBlock(self.name, self._cached_content)
         return None
 
+    def __add__(self, other):
+        if isinstance(other, Message):
+            # Create a new message of the same type as `other`, with `self` prepended.
+            new_items = [self] + other.provider()
+            return type(other)(*new_items)
+        return NotImplemented
+
 class Texts(ContextProvider):
-    def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: Optional[str] = None):
+    def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: Optional[str] = None, visible: bool = True):
         if text is None and name is None:
             raise ValueError("Either 'text' or 'name' must be provided.")
 
@@ -119,7 +126,7 @@ class Texts(ContextProvider):
                 _name = f"text_{h[:8]}"
         else:
             _name = name
-        super().__init__(_name)
+        super().__init__(_name, visible=visible)
 
     async def refresh(self):
         if self._is_dynamic:
@@ -180,8 +187,8 @@ class Texts(ContextProvider):
         return self.content == other.content
 
 class Tools(ContextProvider):
-    def __init__(self, tools_json: Optional[List[Dict]] = None, name: str = "tools"):
-        super().__init__(name)
+    def __init__(self, tools_json: Optional[List[Dict]] = None, name: str = "tools", visible: bool = True):
+        super().__init__(name, visible=visible)
         self._tools_json = tools_json or []
     def update(self, tools_json: List[Dict]):
         self._tools_json = tools_json
@@ -197,8 +204,8 @@ class Tools(ContextProvider):
         return self._tools_json == other._tools_json
 
 class Files(ContextProvider):
-    def __init__(self, *paths: Union[str, List[str]], name: str = "files"):
-        super().__init__(name)
+    def __init__(self, *paths: Union[str, List[str]], name: str = "files", visible: bool = True):
+        super().__init__(name, visible=visible)
         self._files: Dict[str, str] = {}
 
         file_paths: List[str] = []
@@ -278,8 +285,8 @@ class Files(ContextProvider):
         return self._files == other._files
 
 class Images(ContextProvider):
-    def __init__(self, url: str, name: Optional[str] = None):
-        super().__init__(name or url)
+    def __init__(self, url: str, name: Optional[str] = None, visible: bool = True):
+        super().__init__(name or url, visible=visible)
         self.url = url
     def update(self, url: str):
         self.url = url
@@ -654,7 +661,7 @@ class Messages:
             with open(file_path, 'rb') as f:
                 return pickle.load(f)
         except FileNotFoundError:
-            logging.warning(f"File not found at {file_path}, returning empty Messages.")
+            # logging.warning(f"File not found at {file_path}, returning empty Messages.")
             return cls()
         except (pickle.UnpicklingError, EOFError) as e:
             logging.error(f"Could not deserialize file {file_path}: {e}")
@@ -665,30 +672,48 @@ class Messages:
             return Messages(*self._messages[index])
         return self._messages[index]
 
-    def __setitem__(self, index: slice, value: 'Messages'):
-        if not isinstance(index, slice) or not isinstance(value, Messages):
-            raise TypeError("Unsupported operand type(s) for slice assignment")
+    def __setitem__(self, index: Union[int, slice], value: Union[Message, 'Messages']):
+        if isinstance(index, int):
+            if not isinstance(value, Message):
+                raise TypeError("When assigning to an index, the value must be a Message.")
 
-        # Basic slice assignment logic.
-        # A more robust implementation would handle step and negative indices.
-        start, stop, step = index.indices(len(self._messages))
+            if not (-len(self._messages) <= index < len(self._messages)):
+                raise IndexError("Messages assignment index out of range")
 
-        if step != 1:
-            raise ValueError("Slice assignment with step is not supported.")
-
-        # Remove old providers from the index
-        for i in range(start, stop):
-            for provider in self._messages[i].provider():
+            # Get old message to remove its providers
+            old_message = self._messages[index]
+            for provider in old_message.provider():
                 self._notify_provider_removed(provider)
 
-        # Replace the slice in the list
-        self._messages[start:stop] = value._messages
+            # Assign new message
+            self._messages[index] = value
+            value._parent_messages = self
+            for provider in value.provider():
+                self._notify_provider_added(provider, value)
 
-        # Add new providers to the index and set parent
-        for msg in value:
-            msg._parent_messages = self
-            for provider in msg.provider():
-                self._notify_provider_added(provider, msg)
+        elif isinstance(index, slice):
+            if not isinstance(value, Messages):
+                raise TypeError("When assigning to a slice, the value must be a Messages object.")
+
+            start, stop, step = index.indices(len(self._messages))
+            if step != 1:
+                raise ValueError("Slice assignment with step is not supported.")
+
+            # Remove old providers from the index
+            for i in range(start, stop):
+                for provider in self._messages[i].provider():
+                    self._notify_provider_removed(provider)
+
+            # Replace the slice in the list
+            self._messages[start:stop] = value._messages
+
+            # Add new providers to the index and set parent
+            for msg in value:
+                msg._parent_messages = self
+                for provider in msg.provider():
+                    self._notify_provider_added(provider, msg)
+        else:
+            raise TypeError("Unsupported operand type(s) for assignment")
 
     def __len__(self) -> int: return len(self._messages)
     def __iter__(self): return iter(self._messages)
